@@ -106,13 +106,13 @@ signed_from_cp <- function(cp){
   return(raw_val)
 }
 
-# helper: cap infinite values at 100 (preserves sign) and apply tanh normalization; vectorized and scalar-safe.
-cap_inf100_scalar <- function(v, cap = 100, scaling_factor = 2){  # switched to scaling_factor=2 to match log-ratio normalization
+# helper: cap infinite values at 100 (preserves sign) 
+cap_inf100_scalar <- function(v, cap = 100){  
   v2 <- v
   v2[is.infinite(v2)] <- sign(v2[is.infinite(v2)]) * cap
   v2 <- ifelse(abs(v2) > cap, sign(v2) * cap, v2)
   return(v2)
-#  return(tanh(v2 / scaling_factor))
+
 }
 
 
@@ -129,8 +129,8 @@ NNS.caus_core <- function(x, y = NULL,
                           permute = c("y","x","both"),
                           seed = NULL,
                           conf.int = 0.95){
-  if(!is.null(y))  if(sum(is.na(cbind(x,y))) > 0) stop("You have some missing values, please address.")
-  if(is.null(y))  if(sum(is.na(x)) > 0) stop("You have some missing values, please address.")
+  if(!is.null(y))  if(anyNA(cbind(x,y))) stop("You have some missing values, please address.")
+  if(is.null(y))  if(anyNA(x)) stop("You have some missing values, please address.")
   
   orig.tau <- tau
   orig.plot <- plot
